Index: trunk/pswarp/src/pswarpArguments.c
===================================================================
--- trunk/pswarp/src/pswarpArguments.c	(revision 21323)
+++ trunk/pswarp/src/pswarpArguments.c	(revision 21368)
@@ -6,6 +6,6 @@
  *
  *  @author IfA
- *  @version $Revision: 1.23 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2009-02-05 20:44:04 $
+ *  @version $Revision: 1.24 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2009-02-06 03:10:36 $
  *  Copyright 2009 Institute for Astronomy, University of Hawaii
  */
@@ -92,7 +92,7 @@
     }
 
     // the mask and weight entries are optional (build from gain?)
     pmConfigFileSetsMD (config->arguments, &argc, argv, "MASK",   "-mask",   "-masklist");
-    pmConfigFileSetsMD (config->arguments, &argc, argv, "WEIGHT", "-weight", "-weightlist");
+    pmConfigFileSetsMD (config->arguments, &argc, argv, "VARIANCE", "-variance", "-variancelist");
 
     if (argc != 3) {
@@ -92,7 +92,7 @@
     }
 
-    // the mask and weight entries are optional (build from gain?)
+    // the mask and variance entries are optional (build from gain?)
     pmConfigFileSetsMD (config->arguments, &argc, argv, "MASK",   "-mask",   "-masklist");
